// Code generated by protoc-gen-go. DO NOT EDIT.
// source: protoc-gen-swagger/options/openapiv2.proto

/*
Package options is a generated protocol buffer package.

It is generated from these files:
	protoc-gen-swagger/options/openapiv2.proto
	protoc-gen-swagger/options/annotations.proto

It has these top-level messages:
	Swagger
	Operation
	Info
	Contact
	ExternalDocumentation
	Schema
	JSONSchema
	Tag
*/
package options

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import google_protobuf "github.com/golang/protobuf/ptypes/any"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

type Swagger_SwaggerScheme int32

const (
	Swagger_UNKNOWN Swagger_SwaggerScheme = 0
	Swagger_HTTP    Swagger_SwaggerScheme = 1
	Swagger_HTTPS   Swagger_SwaggerScheme = 2
	Swagger_WS      Swagger_SwaggerScheme = 3
	Swagger_WSS     Swagger_SwaggerScheme = 4
)

var Swagger_SwaggerScheme_name = map[int32]string{
	0: "UNKNOWN",
	1: "HTTP",
	2: "HTTPS",
	3: "WS",
	4: "WSS",
}
var Swagger_SwaggerScheme_value = map[string]int32{
	"UNKNOWN": 0,
	"HTTP":    1,
	"HTTPS":   2,
	"WS":      3,
	"WSS":     4,
}

func (x Swagger_SwaggerScheme) String() string {
	return proto.EnumName(Swagger_SwaggerScheme_name, int32(x))
}
func (Swagger_SwaggerScheme) EnumDescriptor() ([]byte, []int) { return fileDescriptor0, []int{0, 0} }

type JSONSchema_JSONSchemaSimpleTypes int32

const (
	JSONSchema_UNKNOWN JSONSchema_JSONSchemaSimpleTypes = 0
	JSONSchema_ARRAY   JSONSchema_JSONSchemaSimpleTypes = 1
	JSONSchema_BOOLEAN JSONSchema_JSONSchemaSimpleTypes = 2
	JSONSchema_INTEGER JSONSchema_JSONSchemaSimpleTypes = 3
	JSONSchema_NULL    JSONSchema_JSONSchemaSimpleTypes = 4
	JSONSchema_NUMBER  JSONSchema_JSONSchemaSimpleTypes = 5
	JSONSchema_OBJECT  JSONSchema_JSONSchemaSimpleTypes = 6
	JSONSchema_STRING  JSONSchema_JSONSchemaSimpleTypes = 7
)

var JSONSchema_JSONSchemaSimpleTypes_name = map[int32]string{
	0: "UNKNOWN",
	1: "ARRAY",
	2: "BOOLEAN",
	3: "INTEGER",
	4: "NULL",
	5: "NUMBER",
	6: "OBJECT",
	7: "STRING",
}
var JSONSchema_JSONSchemaSimpleTypes_value = map[string]int32{
	"UNKNOWN": 0,
	"ARRAY":   1,
	"BOOLEAN": 2,
	"INTEGER": 3,
	"NULL":    4,
	"NUMBER":  5,
	"OBJECT":  6,
	"STRING":  7,
}

func (x JSONSchema_JSONSchemaSimpleTypes) String() string {
	return proto.EnumName(JSONSchema_JSONSchemaSimpleTypes_name, int32(x))
}
func (JSONSchema_JSONSchemaSimpleTypes) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor0, []int{6, 0}
}

// `Swagger` is a representation of OpenAPI v2 specification's Swagger object.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#swaggerObject
//
// TODO(ivucica): document fields
type Swagger struct {
	Swagger      string                  `protobuf:"bytes,1,opt,name=swagger" json:"swagger,omitempty"`
	Info         *Info                   `protobuf:"bytes,2,opt,name=info" json:"info,omitempty"`
	Host         string                  `protobuf:"bytes,3,opt,name=host" json:"host,omitempty"`
	BasePath     string                  `protobuf:"bytes,4,opt,name=base_path,json=basePath" json:"base_path,omitempty"`
	Schemes      []Swagger_SwaggerScheme `protobuf:"varint,5,rep,packed,name=schemes,enum=grpc.gateway.protoc_gen_swagger.options.Swagger_SwaggerScheme" json:"schemes,omitempty"`
	Consumes     []string                `protobuf:"bytes,6,rep,name=consumes" json:"consumes,omitempty"`
	Produces     []string                `protobuf:"bytes,7,rep,name=produces" json:"produces,omitempty"`
	ExternalDocs *ExternalDocumentation  `protobuf:"bytes,14,opt,name=external_docs,json=externalDocs" json:"external_docs,omitempty"`
}

func (m *Swagger) Reset()                    { *m = Swagger{} }
func (m *Swagger) String() string            { return proto.CompactTextString(m) }
func (*Swagger) ProtoMessage()               {}
func (*Swagger) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{0} }

func (m *Swagger) GetSwagger() string {
	if m != nil {
		return m.Swagger
	}
	return ""
}

func (m *Swagger) GetInfo() *Info {
	if m != nil {
		return m.Info
	}
	return nil
}

func (m *Swagger) GetHost() string {
	if m != nil {
		return m.Host
	}
	return ""
}

func (m *Swagger) GetBasePath() string {
	if m != nil {
		return m.BasePath
	}
	return ""
}

func (m *Swagger) GetSchemes() []Swagger_SwaggerScheme {
	if m != nil {
		return m.Schemes
	}
	return nil
}

func (m *Swagger) GetConsumes() []string {
	if m != nil {
		return m.Consumes
	}
	return nil
}

func (m *Swagger) GetProduces() []string {
	if m != nil {
		return m.Produces
	}
	return nil
}

func (m *Swagger) GetExternalDocs() *ExternalDocumentation {
	if m != nil {
		return m.ExternalDocs
	}
	return nil
}

// `Operation` is a representation of OpenAPI v2 specification's Operation object.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#operationObject
//
// TODO(ivucica): document fields
type Operation struct {
	Tags         []string               `protobuf:"bytes,1,rep,name=tags" json:"tags,omitempty"`
	Summary      string                 `protobuf:"bytes,2,opt,name=summary" json:"summary,omitempty"`
	Description  string                 `protobuf:"bytes,3,opt,name=description" json:"description,omitempty"`
	ExternalDocs *ExternalDocumentation `protobuf:"bytes,4,opt,name=external_docs,json=externalDocs" json:"external_docs,omitempty"`
	OperationId  string                 `protobuf:"bytes,5,opt,name=operation_id,json=operationId" json:"operation_id,omitempty"`
	Consumes     []string               `protobuf:"bytes,6,rep,name=consumes" json:"consumes,omitempty"`
	Produces     []string               `protobuf:"bytes,7,rep,name=produces" json:"produces,omitempty"`
	Schemes      []string               `protobuf:"bytes,10,rep,name=schemes" json:"schemes,omitempty"`
	Deprecated   bool                   `protobuf:"varint,11,opt,name=deprecated" json:"deprecated,omitempty"`
}

func (m *Operation) Reset()                    { *m = Operation{} }
func (m *Operation) String() string            { return proto.CompactTextString(m) }
func (*Operation) ProtoMessage()               {}
func (*Operation) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{1} }

func (m *Operation) GetTags() []string {
	if m != nil {
		return m.Tags
	}
	return nil
}

func (m *Operation) GetSummary() string {
	if m != nil {
		return m.Summary
	}
	return ""
}

func (m *Operation) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *Operation) GetExternalDocs() *ExternalDocumentation {
	if m != nil {
		return m.ExternalDocs
	}
	return nil
}

func (m *Operation) GetOperationId() string {
	if m != nil {
		return m.OperationId
	}
	return ""
}

func (m *Operation) GetConsumes() []string {
	if m != nil {
		return m.Consumes
	}
	return nil
}

func (m *Operation) GetProduces() []string {
	if m != nil {
		return m.Produces
	}
	return nil
}

func (m *Operation) GetSchemes() []string {
	if m != nil {
		return m.Schemes
	}
	return nil
}

func (m *Operation) GetDeprecated() bool {
	if m != nil {
		return m.Deprecated
	}
	return false
}

// `Info` is a representation of OpenAPI v2 specification's Info object.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#infoObject
//
// TODO(ivucica): document fields
type Info struct {
	Title          string   `protobuf:"bytes,1,opt,name=title" json:"title,omitempty"`
	Description    string   `protobuf:"bytes,2,opt,name=description" json:"description,omitempty"`
	TermsOfService string   `protobuf:"bytes,3,opt,name=terms_of_service,json=termsOfService" json:"terms_of_service,omitempty"`
	Contact        *Contact `protobuf:"bytes,4,opt,name=contact" json:"contact,omitempty"`
	Version        string   `protobuf:"bytes,6,opt,name=version" json:"version,omitempty"`
}

func (m *Info) Reset()                    { *m = Info{} }
func (m *Info) String() string            { return proto.CompactTextString(m) }
func (*Info) ProtoMessage()               {}
func (*Info) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{2} }

func (m *Info) GetTitle() string {
	if m != nil {
		return m.Title
	}
	return ""
}

func (m *Info) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *Info) GetTermsOfService() string {
	if m != nil {
		return m.TermsOfService
	}
	return ""
}

func (m *Info) GetContact() *Contact {
	if m != nil {
		return m.Contact
	}
	return nil
}

func (m *Info) GetVersion() string {
	if m != nil {
		return m.Version
	}
	return ""
}

// `Contact` is a representation of OpenAPI v2 specification's Contact object.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#contactObject
//
// TODO(ivucica): document fields
type Contact struct {
	Name  string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
	Url   string `protobuf:"bytes,2,opt,name=url" json:"url,omitempty"`
	Email string `protobuf:"bytes,3,opt,name=email" json:"email,omitempty"`
}

func (m *Contact) Reset()                    { *m = Contact{} }
func (m *Contact) String() string            { return proto.CompactTextString(m) }
func (*Contact) ProtoMessage()               {}
func (*Contact) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{3} }

func (m *Contact) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *Contact) GetUrl() string {
	if m != nil {
		return m.Url
	}
	return ""
}

func (m *Contact) GetEmail() string {
	if m != nil {
		return m.Email
	}
	return ""
}

// `ExternalDocumentation` is a representation of OpenAPI v2 specification's
// ExternalDocumentation object.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#externalDocumentationObject
//
// TODO(ivucica): document fields
type ExternalDocumentation struct {
	Description string `protobuf:"bytes,1,opt,name=description" json:"description,omitempty"`
	Url         string `protobuf:"bytes,2,opt,name=url" json:"url,omitempty"`
}

func (m *ExternalDocumentation) Reset()                    { *m = ExternalDocumentation{} }
func (m *ExternalDocumentation) String() string            { return proto.CompactTextString(m) }
func (*ExternalDocumentation) ProtoMessage()               {}
func (*ExternalDocumentation) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{4} }

func (m *ExternalDocumentation) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *ExternalDocumentation) GetUrl() string {
	if m != nil {
		return m.Url
	}
	return ""
}

// `Schema` is a representation of OpenAPI v2 specification's Schema object.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#schemaObject
//
// TODO(ivucica): document fields
type Schema struct {
	JsonSchema    *JSONSchema            `protobuf:"bytes,1,opt,name=json_schema,json=jsonSchema" json:"json_schema,omitempty"`
	Discriminator string                 `protobuf:"bytes,2,opt,name=discriminator" json:"discriminator,omitempty"`
	ReadOnly      bool                   `protobuf:"varint,3,opt,name=read_only,json=readOnly" json:"read_only,omitempty"`
	ExternalDocs  *ExternalDocumentation `protobuf:"bytes,5,opt,name=external_docs,json=externalDocs" json:"external_docs,omitempty"`
	Example       *google_protobuf.Any   `protobuf:"bytes,6,opt,name=example" json:"example,omitempty"`
}

func (m *Schema) Reset()                    { *m = Schema{} }
func (m *Schema) String() string            { return proto.CompactTextString(m) }
func (*Schema) ProtoMessage()               {}
func (*Schema) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{5} }

func (m *Schema) GetJsonSchema() *JSONSchema {
	if m != nil {
		return m.JsonSchema
	}
	return nil
}

func (m *Schema) GetDiscriminator() string {
	if m != nil {
		return m.Discriminator
	}
	return ""
}

func (m *Schema) GetReadOnly() bool {
	if m != nil {
		return m.ReadOnly
	}
	return false
}

func (m *Schema) GetExternalDocs() *ExternalDocumentation {
	if m != nil {
		return m.ExternalDocs
	}
	return nil
}

func (m *Schema) GetExample() *google_protobuf.Any {
	if m != nil {
		return m.Example
	}
	return nil
}

// `JSONSchema` represents properties from JSON Schema taken, and as used, in
// the OpenAPI v2 spec.
//
// This includes changes made by OpenAPI v2.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#schemaObject
//
// See also: https://cswr.github.io/JsonSchema/spec/basic_types/,
// https://github.com/json-schema-org/json-schema-spec/blob/master/schema.json
//
// TODO(ivucica): document fields
type JSONSchema struct {
	Title            string   `protobuf:"bytes,5,opt,name=title" json:"title,omitempty"`
	Description      string   `protobuf:"bytes,6,opt,name=description" json:"description,omitempty"`
	Default          string   `protobuf:"bytes,7,opt,name=default" json:"default,omitempty"`
	MultipleOf       float64  `protobuf:"fixed64,10,opt,name=multiple_of,json=multipleOf" json:"multiple_of,omitempty"`
	Maximum          float64  `protobuf:"fixed64,11,opt,name=maximum" json:"maximum,omitempty"`
	ExclusiveMaximum bool     `protobuf:"varint,12,opt,name=exclusive_maximum,json=exclusiveMaximum" json:"exclusive_maximum,omitempty"`
	Minimum          float64  `protobuf:"fixed64,13,opt,name=minimum" json:"minimum,omitempty"`
	ExclusiveMinimum bool     `protobuf:"varint,14,opt,name=exclusive_minimum,json=exclusiveMinimum" json:"exclusive_minimum,omitempty"`
	MaxLength        uint64   `protobuf:"varint,15,opt,name=max_length,json=maxLength" json:"max_length,omitempty"`
	MinLength        uint64   `protobuf:"varint,16,opt,name=min_length,json=minLength" json:"min_length,omitempty"`
	Pattern          string   `protobuf:"bytes,17,opt,name=pattern" json:"pattern,omitempty"`
	MaxItems         uint64   `protobuf:"varint,20,opt,name=max_items,json=maxItems" json:"max_items,omitempty"`
	MinItems         uint64   `protobuf:"varint,21,opt,name=min_items,json=minItems" json:"min_items,omitempty"`
	UniqueItems      bool     `protobuf:"varint,22,opt,name=unique_items,json=uniqueItems" json:"unique_items,omitempty"`
	MaxProperties    uint64   `protobuf:"varint,24,opt,name=max_properties,json=maxProperties" json:"max_properties,omitempty"`
	MinProperties    uint64   `protobuf:"varint,25,opt,name=min_properties,json=minProperties" json:"min_properties,omitempty"`
	Required         []string `protobuf:"bytes,26,rep,name=required" json:"required,omitempty"`
	// Items in 'array' must be unique.
	Array []string                           `protobuf:"bytes,34,rep,name=array" json:"array,omitempty"`
	Type  []JSONSchema_JSONSchemaSimpleTypes `protobuf:"varint,35,rep,packed,name=type,enum=grpc.gateway.protoc_gen_swagger.options.JSONSchema_JSONSchemaSimpleTypes" json:"type,omitempty"`
}

func (m *JSONSchema) Reset()                    { *m = JSONSchema{} }
func (m *JSONSchema) String() string            { return proto.CompactTextString(m) }
func (*JSONSchema) ProtoMessage()               {}
func (*JSONSchema) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{6} }

func (m *JSONSchema) GetTitle() string {
	if m != nil {
		return m.Title
	}
	return ""
}

func (m *JSONSchema) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *JSONSchema) GetDefault() string {
	if m != nil {
		return m.Default
	}
	return ""
}

func (m *JSONSchema) GetMultipleOf() float64 {
	if m != nil {
		return m.MultipleOf
	}
	return 0
}

func (m *JSONSchema) GetMaximum() float64 {
	if m != nil {
		return m.Maximum
	}
	return 0
}

func (m *JSONSchema) GetExclusiveMaximum() bool {
	if m != nil {
		return m.ExclusiveMaximum
	}
	return false
}

func (m *JSONSchema) GetMinimum() float64 {
	if m != nil {
		return m.Minimum
	}
	return 0
}

func (m *JSONSchema) GetExclusiveMinimum() bool {
	if m != nil {
		return m.ExclusiveMinimum
	}
	return false
}

func (m *JSONSchema) GetMaxLength() uint64 {
	if m != nil {
		return m.MaxLength
	}
	return 0
}

func (m *JSONSchema) GetMinLength() uint64 {
	if m != nil {
		return m.MinLength
	}
	return 0
}

func (m *JSONSchema) GetPattern() string {
	if m != nil {
		return m.Pattern
	}
	return ""
}

func (m *JSONSchema) GetMaxItems() uint64 {
	if m != nil {
		return m.MaxItems
	}
	return 0
}

func (m *JSONSchema) GetMinItems() uint64 {
	if m != nil {
		return m.MinItems
	}
	return 0
}

func (m *JSONSchema) GetUniqueItems() bool {
	if m != nil {
		return m.UniqueItems
	}
	return false
}

func (m *JSONSchema) GetMaxProperties() uint64 {
	if m != nil {
		return m.MaxProperties
	}
	return 0
}

func (m *JSONSchema) GetMinProperties() uint64 {
	if m != nil {
		return m.MinProperties
	}
	return 0
}

func (m *JSONSchema) GetRequired() []string {
	if m != nil {
		return m.Required
	}
	return nil
}

func (m *JSONSchema) GetArray() []string {
	if m != nil {
		return m.Array
	}
	return nil
}

func (m *JSONSchema) GetType() []JSONSchema_JSONSchemaSimpleTypes {
	if m != nil {
		return m.Type
	}
	return nil
}

// `Tag` is a representation of OpenAPI v2 specification's Tag object.
//
// See: https://github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#tagObject
//
// TODO(ivucica): document fields
type Tag struct {
	// TODO(ivucica): Description should be extracted from comments on the proto
	// service object.
	Description  string                 `protobuf:"bytes,2,opt,name=description" json:"description,omitempty"`
	ExternalDocs *ExternalDocumentation `protobuf:"bytes,3,opt,name=external_docs,json=externalDocs" json:"external_docs,omitempty"`
}

func (m *Tag) Reset()                    { *m = Tag{} }
func (m *Tag) String() string            { return proto.CompactTextString(m) }
func (*Tag) ProtoMessage()               {}
func (*Tag) Descriptor() ([]byte, []int) { return fileDescriptor0, []int{7} }

func (m *Tag) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *Tag) GetExternalDocs() *ExternalDocumentation {
	if m != nil {
		return m.ExternalDocs
	}
	return nil
}

func init() {
	proto.RegisterType((*Swagger)(nil), "grpc.gateway.protoc_gen_swagger.options.Swagger")
	proto.RegisterType((*Operation)(nil), "grpc.gateway.protoc_gen_swagger.options.Operation")
	proto.RegisterType((*Info)(nil), "grpc.gateway.protoc_gen_swagger.options.Info")
	proto.RegisterType((*Contact)(nil), "grpc.gateway.protoc_gen_swagger.options.Contact")
	proto.RegisterType((*ExternalDocumentation)(nil), "grpc.gateway.protoc_gen_swagger.options.ExternalDocumentation")
	proto.RegisterType((*Schema)(nil), "grpc.gateway.protoc_gen_swagger.options.Schema")
	proto.RegisterType((*JSONSchema)(nil), "grpc.gateway.protoc_gen_swagger.options.JSONSchema")
	proto.RegisterType((*Tag)(nil), "grpc.gateway.protoc_gen_swagger.options.Tag")
	proto.RegisterEnum("grpc.gateway.protoc_gen_swagger.options.Swagger_SwaggerScheme", Swagger_SwaggerScheme_name, Swagger_SwaggerScheme_value)
	proto.RegisterEnum("grpc.gateway.protoc_gen_swagger.options.JSONSchema_JSONSchemaSimpleTypes", JSONSchema_JSONSchemaSimpleTypes_name, JSONSchema_JSONSchemaSimpleTypes_value)
}

func init() { proto.RegisterFile("protoc-gen-swagger/options/openapiv2.proto", fileDescriptor0) }

var fileDescriptor0 = []byte{
	// 1175 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xb4, 0x56, 0xed, 0x6e, 0xdb, 0x36,
	0x17, 0x7e, 0x65, 0xd3, 0x36, 0x7d, 0x6c, 0xe7, 0x65, 0xd5, 0x74, 0x63, 0xd3, 0x8f, 0xb9, 0x5e,
	0x87, 0x19, 0x2d, 0xe2, 0x0c, 0xe9, 0xff, 0x01, 0x49, 0x67, 0x74, 0x51, 0x53, 0xbb, 0x90, 0x5d,
	0x74, 0x1b, 0x30, 0x18, 0x8c, 0x4c, 0x3b, 0x1c, 0x24, 0x4a, 0x95, 0xa8, 0xd4, 0xbe, 0x8d, 0x5d,
	0xcf, 0x2e, 0x63, 0xf7, 0xb0, 0x3b, 0xd8, 0x8f, 0xfd, 0x1a, 0x48, 0x51, 0xf9, 0x72, 0x37, 0x04,
	0x45, 0xf7, 0xcb, 0x3c, 0xcf, 0x73, 0xce, 0x23, 0x9e, 0x0f, 0x92, 0x86, 0x27, 0x49, 0x1a, 0xab,
	0x38, 0xd8, 0x5d, 0x72, 0xb9, 0x9b, 0xbd, 0x67, 0xcb, 0x25, 0x4f, 0xf7, 0xe2, 0x44, 0x89, 0x58,
	0x66, 0x7b, 0x71, 0xc2, 0x25, 0x4b, 0xc4, 0xd9, 0xfe, 0xc0, 0x38, 0xb9, 0x5f, 0x2f, 0xd3, 0x24,
	0x18, 0x2c, 0x99, 0xe2, 0xef, 0xd9, 0xba, 0xc0, 0x82, 0xd9, 0x92, 0xcb, 0x99, 0x0d, 0x1c, 0xd8,
	0xc0, 0x9d, 0xbb, 0xcb, 0x38, 0x5e, 0x86, 0x7c, 0xcf, 0xb8, 0x9c, 0xe4, 0x8b, 0x3d, 0x26, 0xad,
	0x7f, 0xef, 0xcf, 0x2a, 0x34, 0x26, 0x85, 0xbb, 0x4b, 0xa1, 0x61, 0x23, 0xa9, 0xd3, 0x75, 0xfa,
	0x4d, 0xbf, 0x34, 0xdd, 0x03, 0x40, 0x42, 0x2e, 0x62, 0x5a, 0xe9, 0x3a, 0xfd, 0xd6, 0xfe, 0xee,
	0xe0, 0x86, 0x1f, 0x1e, 0x1c, 0xc9, 0x45, 0xec, 0x9b, 0x50, 0xd7, 0x05, 0x74, 0x1a, 0x67, 0x8a,
	0x56, 0x8d, 0xb2, 0x59, 0xbb, 0xf7, 0xa0, 0x79, 0xc2, 0x32, 0x3e, 0x4b, 0x98, 0x3a, 0xa5, 0xc8,
	0x10, 0x58, 0x03, 0xaf, 0x99, 0x3a, 0x75, 0x7f, 0x80, 0x46, 0x16, 0x9c, 0xf2, 0x88, 0x67, 0xb4,
	0xd6, 0xad, 0xf6, 0xb7, 0xf6, 0xbf, 0xbd, 0xf1, 0x67, 0x6d, 0x42, 0xe5, 0xef, 0xc4, 0xc8, 0xf8,
	0xa5, 0x9c, 0xbb, 0x03, 0x38, 0x88, 0x65, 0x96, 0x6b, 0xe9, 0x7a, 0xb7, 0xaa, 0xbf, 0x5a, 0xda,
	0x9a, 0x4b, 0xd2, 0x78, 0x9e, 0x07, 0x3c, 0xa3, 0x8d, 0x82, 0x2b, 0x6d, 0x37, 0x80, 0x0e, 0x5f,
	0x29, 0x9e, 0x4a, 0x16, 0xce, 0xe6, 0x71, 0x90, 0xd1, 0x2d, 0x53, 0x8e, 0x9b, 0xef, 0x6b, 0x68,
	0xa3, 0xbf, 0x8b, 0x83, 0x3c, 0xe2, 0x52, 0x31, 0x0d, 0xfb, 0x6d, 0x7e, 0x01, 0x67, 0xbd, 0x43,
	0xe8, 0x5c, 0xd9, 0xb6, 0xdb, 0x82, 0xc6, 0x9b, 0xd1, 0xcb, 0xd1, 0xf8, 0xed, 0x88, 0xfc, 0xcf,
	0xc5, 0x80, 0xbe, 0x9f, 0x4e, 0x5f, 0x13, 0xc7, 0x6d, 0x42, 0x4d, 0xaf, 0x26, 0xa4, 0xe2, 0xd6,
	0xa1, 0xf2, 0x76, 0x42, 0xaa, 0x6e, 0x03, 0xaa, 0x6f, 0x27, 0x13, 0x82, 0x3c, 0x84, 0x31, 0x69,
	0x7a, 0x08, 0x37, 0x09, 0x78, 0x08, 0x03, 0x69, 0x79, 0x08, 0xb7, 0x48, 0xdb, 0x43, 0xb8, 0x4d,
	0x3a, 0x1e, 0xc2, 0x1d, 0xb2, 0xd5, 0xfb, 0xa3, 0x02, 0xcd, 0x71, 0xc2, 0x53, 0xb3, 0x07, 0xdd,
	0x1d, 0xc5, 0x96, 0x19, 0x75, 0x4c, 0xca, 0x66, 0x6d, 0xc6, 0x21, 0x8f, 0x22, 0x96, 0xae, 0x4d,
	0xdf, 0xf5, 0x38, 0x14, 0xa6, 0xdb, 0x85, 0xd6, 0x9c, 0x67, 0x41, 0x2a, 0x4c, 0x5e, 0xb6, 0xa5,
	0x97, 0xa1, 0xcd, 0x52, 0xa1, 0x4f, 0x5f, 0x2a, 0xf7, 0x11, 0xb4, 0xe3, 0x32, 0x83, 0x99, 0x98,
	0xd3, 0x5a, 0xb1, 0x8f, 0x73, 0xec, 0x68, 0xfe, 0xd1, 0xad, 0xa6, 0x17, 0xc3, 0x07, 0x86, 0x3a,
	0x1f, 0x9e, 0x87, 0x00, 0x73, 0x9e, 0xa4, 0x3c, 0x60, 0x8a, 0xcf, 0x69, 0xab, 0xeb, 0xf4, 0xb1,
	0x7f, 0x09, 0xb9, 0x56, 0xfb, 0x36, 0xe9, 0xf4, 0x7e, 0x77, 0x00, 0xe9, 0x83, 0xe0, 0x6e, 0x43,
	0x4d, 0x09, 0x15, 0x72, 0x7b, 0xba, 0x0a, 0xe3, 0x7a, 0x31, 0x2b, 0x9b, 0xc5, 0xec, 0x03, 0x51,
	0x3c, 0x8d, 0xb2, 0x59, 0xbc, 0x98, 0x65, 0x3c, 0x3d, 0x13, 0x01, 0xb7, 0x35, 0xdf, 0x32, 0xf8,
	0x78, 0x31, 0x29, 0x50, 0xd7, 0x83, 0x46, 0x10, 0x4b, 0xc5, 0x02, 0x65, 0x0b, 0xfe, 0xcd, 0x8d,
	0x0b, 0xfe, 0xbc, 0x88, 0xf3, 0x4b, 0x01, 0x5d, 0x82, 0x33, 0x9e, 0x66, 0x7a, 0x4f, 0xf5, 0xa2,
	0xfd, 0xd6, 0xf4, 0x10, 0xae, 0x91, 0x7a, 0x6f, 0x08, 0x0d, 0x1b, 0xa3, 0xa7, 0x47, 0xb2, 0xa8,
	0xcc, 0xcb, 0xac, 0x5d, 0x02, 0xd5, 0x3c, 0x0d, 0x6d, 0x3a, 0x7a, 0xa9, 0xd3, 0xe7, 0x11, 0x13,
	0xa1, 0xdd, 0x7b, 0x61, 0xf4, 0x5e, 0xc2, 0x9d, 0x0f, 0xf6, 0xfa, 0x7a, 0x5d, 0x9c, 0xcd, 0xba,
	0x6c, 0x7c, 0xa2, 0xf7, 0x5b, 0x05, 0xea, 0xe6, 0xd8, 0x30, 0x77, 0x0a, 0xad, 0x5f, 0xb2, 0x58,
	0xce, 0x4c, 0xdf, 0x98, 0x09, 0x6f, 0xed, 0x3f, 0xbb, 0x71, 0x39, 0xbc, 0xc9, 0x78, 0x54, 0x28,
	0xf9, 0xa0, 0x75, 0xac, 0xea, 0x63, 0xe8, 0xcc, 0x85, 0xde, 0x41, 0x24, 0x24, 0x53, 0x71, 0x6a,
	0x3f, 0x7e, 0x15, 0xd4, 0xf7, 0x5a, 0xca, 0xd9, 0x7c, 0x16, 0xcb, 0x70, 0x6d, 0xb2, 0xc5, 0x3e,
	0xd6, 0xc0, 0x58, 0x86, 0xeb, 0xcd, 0xa3, 0x51, 0xfb, 0x0f, 0x8e, 0xc6, 0x00, 0x1a, 0x7c, 0xc5,
	0xa2, 0x24, 0xe4, 0xa6, 0x79, 0xad, 0xfd, 0xed, 0x41, 0xf1, 0x06, 0x0c, 0xca, 0x37, 0x60, 0x70,
	0x20, 0xd7, 0x7e, 0xe9, 0xe4, 0x21, 0x8c, 0x48, 0xad, 0xf7, 0x57, 0x1d, 0xe0, 0x22, 0xf1, 0x8b,
	0x79, 0xad, 0xfd, 0xcb, 0xbc, 0xd6, 0x37, 0xfb, 0x42, 0xa1, 0x31, 0xe7, 0x0b, 0x96, 0x87, 0x8a,
	0x36, 0x8a, 0xc9, 0xb1, 0xa6, 0xfb, 0x05, 0xb4, 0xa2, 0x3c, 0x54, 0x22, 0x09, 0xf9, 0x2c, 0x5e,
	0x50, 0xe8, 0x3a, 0x7d, 0xc7, 0x87, 0x12, 0x1a, 0x2f, 0x74, 0x68, 0xc4, 0x56, 0x22, 0xca, 0x23,
	0x73, 0xb4, 0x1c, 0xbf, 0x34, 0xdd, 0xa7, 0x70, 0x8b, 0xaf, 0x82, 0x30, 0xcf, 0xc4, 0x19, 0x9f,
	0x95, 0x3e, 0x6d, 0x53, 0x5b, 0x72, 0x4e, 0xbc, 0xb2, 0xce, 0x5a, 0x46, 0x48, 0xe3, 0xd2, 0xb1,
	0x32, 0x85, 0x79, 0x4d, 0xc6, 0xfa, 0x6c, 0x5d, 0x97, 0xb1, 0xce, 0x0f, 0x00, 0x22, 0xb6, 0x9a,
	0x85, 0x5c, 0x2e, 0xd5, 0x29, 0xfd, 0x7f, 0xd7, 0xe9, 0x23, 0xbf, 0x19, 0xb1, 0xd5, 0xb1, 0x01,
	0x0c, 0x2d, 0x64, 0x49, 0x13, 0x4b, 0x0b, 0x69, 0x69, 0x0a, 0x8d, 0x84, 0x29, 0xdd, 0x14, 0x7a,
	0xab, 0x28, 0x83, 0x35, 0xf5, 0x7c, 0x68, 0x5d, 0xa1, 0x78, 0x94, 0xd1, 0x6d, 0x13, 0x87, 0x23,
	0xb6, 0x3a, 0xd2, 0xb6, 0x21, 0x85, 0xb4, 0xe4, 0x1d, 0x4b, 0x0a, 0x59, 0x90, 0x8f, 0xa0, 0x9d,
	0x4b, 0xf1, 0x2e, 0xe7, 0x96, 0xff, 0xcc, 0xec, 0xbc, 0x55, 0x60, 0x85, 0xcb, 0x57, 0xb0, 0xa5,
	0xc5, 0x93, 0x54, 0xdf, 0x83, 0x4a, 0xf0, 0x8c, 0x52, 0x23, 0xd2, 0x89, 0xd8, 0xea, 0xf5, 0x39,
	0x68, 0xdc, 0x84, 0xbc, 0xec, 0x76, 0xd7, 0xba, 0x09, 0x79, 0xc9, 0x6d, 0x07, 0x70, 0xca, 0xdf,
	0xe5, 0x22, 0xe5, 0x73, 0xba, 0x53, 0x5c, 0x92, 0xa5, 0xad, 0xe7, 0x83, 0xa5, 0x29, 0x5b, 0xd3,
	0x9e, 0x21, 0x0a, 0xc3, 0xfd, 0x19, 0x90, 0x5a, 0x27, 0x9c, 0x7e, 0x69, 0x1e, 0xed, 0xa3, 0x8f,
	0x38, 0x71, 0x97, 0x96, 0x13, 0xa1, 0xc7, 0x73, 0xba, 0x4e, 0x78, 0xe6, 0x1b, 0xd9, 0xde, 0x7b,
	0xb8, 0xf3, 0x41, 0xfa, 0xea, 0x3b, 0xd9, 0x84, 0xda, 0x81, 0xef, 0x1f, 0xfc, 0x48, 0x1c, 0x8d,
	0x1f, 0x8e, 0xc7, 0xc7, 0xc3, 0x83, 0x11, 0xa9, 0x68, 0xe3, 0x68, 0x34, 0x1d, 0xbe, 0x18, 0xfa,
	0xa4, 0xaa, 0x1f, 0xd3, 0xd1, 0x9b, 0xe3, 0x63, 0x82, 0x5c, 0x80, 0xfa, 0xe8, 0xcd, 0xab, 0xc3,
	0xa1, 0x4f, 0x6a, 0x7a, 0x3d, 0x3e, 0xf4, 0x86, 0xcf, 0xa7, 0xa4, 0xae, 0xd7, 0x93, 0xa9, 0x7f,
	0x34, 0x7a, 0x41, 0x1a, 0x1e, 0xc2, 0x0e, 0xa9, 0x78, 0x08, 0x57, 0x48, 0xd5, 0x43, 0xb8, 0x6a,
	0x9e, 0x59, 0x44, 0x6a, 0xd7, 0x2e, 0x7c, 0x97, 0xdc, 0xf6, 0x10, 0xbe, 0x4d, 0xb6, 0x3d, 0x84,
	0x3f, 0x27, 0xd4, 0x43, 0xf8, 0x1e, 0xb9, 0xef, 0x21, 0x7c, 0x9f, 0x3c, 0xf0, 0x10, 0x7e, 0x40,
	0x1e, 0x7a, 0x08, 0x3f, 0x24, 0x3d, 0x0f, 0xe1, 0xc7, 0xe4, 0x89, 0x87, 0xf0, 0x13, 0xf2, 0xd4,
	0x43, 0xf8, 0x29, 0x19, 0xf4, 0x7e, 0x75, 0xa0, 0x3a, 0x65, 0xcb, 0x1b, 0xbc, 0x07, 0x1b, 0x37,
	0x48, 0xf5, 0xd3, 0xdf, 0x20, 0x45, 0xba, 0x87, 0xcf, 0x7f, 0x3a, 0x58, 0x0a, 0x75, 0x9a, 0x9f,
	0x0c, 0x82, 0x38, 0xda, 0xd3, 0xfa, 0xbb, 0x3c, 0x88, 0xb3, 0x75, 0xa6, 0xb8, 0x35, 0xed, 0xe7,
	0xf6, 0xfe, 0xf9, 0x7f, 0xeb, 0x49, 0xdd, 0x70, 0xcf, 0xfe, 0x0e, 0x00, 0x00, 0xff, 0xff, 0xf8,
	0x2b, 0xe7, 0x47, 0xdc, 0x0a, 0x00, 0x00,
}
