/* 
 * A Bit of Everything
 *
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0
 * Contact: none@example.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */

package abe

// NumericEnum is one or zero.   - ZERO: ZERO means 0  - ONE: ONE means 1
type ExamplepbNumericEnum struct {
}
