/* 
 * A Bit of Everything
 *
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0
 * Contact: none@example.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */

package abe

// DeepEnum is one or zero.   - FALSE: FALSE is false.  - TRUE: TRUE is true.
type NestedDeepEnum struct {
}
